package http

import (
	"github.com/gin-gonic/gin"
	"kpt-event/dep"
	"kpt-event/http/middleware"
	"kpt-event/http/route"
)

type Server struct {
	*gin.Engine
}

type Option func(*Server)

func NewServer(options ...Option) *Server {
	s := &Server{
		Engine: gin.New(),
	}

	for _, option := range options {
		option(s)
	}

	return s
}

func ExportLogOption() Option {
	return func(s *Server) {
		s.Engine.Use(gin.LoggerWithConfig(gin.LoggerConfig{SkipPaths: []string{"/metrics", "/check"}}))
	}
}

func SetRouteOption() Option {
	return func(s *Server) {
		route.HTTPServerRoute()(s.Engine)
	}
}

func WithDependency(dep *dep.HttpDependency) Option {
	return func(s *Server) {
		s.Engine.Use(middleware.WithDependency(dep))
	}
}
